@@ -21,6 +21,7 @@ pub(crate) use config::ValBytesMode;
 
 mod any;
 mod arguments;
+mod arguments_v3;
 mod bool;
 mod bytes;
 mod call;
@@ -310,6 +311,7 @@ impl SchemaValidator {
             data: None,
             strict,
             from_attributes,
+            field_name: Some(PyString::new(py, field_name)),
             context,
             self_instance: None,
             cache_str: self.cache_str,
@@ -336,6 +338,7 @@ impl SchemaValidator {
             data: None,
             strict,
             from_attributes: None,
+            field_name: None,
             context,
             self_instance: None,
             cache_str: self.cache_str,
@@ -636,6 +639,7 @@ pub fn build_validator(
         callable::CallableValidator,
         // arguments
         arguments::ArgumentsValidator,
+        arguments_v3::ArgumentsV3Validator,
         // default value
         with_default::WithDefaultValidator,
         // chain validators
@@ -676,6 +680,8 @@ pub struct Extra<'a, 'py> {
     pub from_attributes: Option<bool>,
     /// context used in validator functions
     pub context: Option<&'a Bound<'py, PyAny>>,
+    /// The name of the field being validated, if applicable
+    pub field_name: Option<Bound<'py, PyString>>,
     /// This is an instance of the model or dataclass being validated, when validation is performed from `__init__`
     self_instance: Option<&'a Bound<'py, PyAny>>,
     /// Whether to use a cache of short strings to accelerate python string construction
@@ -703,6 +709,7 @@ impl<'a, 'py> Extra<'a, 'py> {
             data: None,
             strict,
             from_attributes,
+            field_name: None,
             context,
             self_instance,
             cache_str,
@@ -719,6 +726,7 @@ impl Extra<'_, '_> {
             data: self.data.clone(),
             strict: Some(true),
             from_attributes: self.from_attributes,
+            field_name: self.field_name.clone(),
             context: self.context,
             self_instance: self.self_instance,
             cache_str: self.cache_str,
@@ -802,6 +810,7 @@ pub enum CombinedValidator {
     Callable(callable::CallableValidator),
     // arguments
     Arguments(arguments::ArgumentsValidator),
+    ArgumentsV3(arguments_v3::ArgumentsV3Validator),
     // default value
     WithDefault(with_default::WithDefaultValidator),
     // chain validators
